[Zope-CVS] CVS: Products/PluggableAuthService/tests - test_Caching.py:1.1.2.4

Jens Vagelpohl jens at dataflake.org
Mon Nov 8 04:18:08 EST 2004


Update of /cvs-repository/Products/PluggableAuthService/tests
In directory cvs.zope.org:/tmp/cvs-serv9211/tests

Modified Files:
      Tag: jens-implement_caching_branch
	test_Caching.py 
Log Message:
- revert to use RAM Cache Manager, which will receive the improvements
  that the PAS RAM Cache Manager had


=== Products/PluggableAuthService/tests/test_Caching.py 1.1.2.3 => 1.1.2.4 ===
--- Products/PluggableAuthService/tests/test_Caching.py:1.1.2.3	Mon Nov  8 02:13:38 2004
+++ Products/PluggableAuthService/tests/test_Caching.py	Mon Nov  8 04:17:37 2004
@@ -17,7 +17,7 @@
 from Acquisition import aq_base
 from OFS.Cache import isCacheable
 
-from Products.PluggableAuthService.PASCache import PASRAMCacheManager
+from Products.StandardCacheManagers.RAMCacheManager import RAMCacheManager
 
 class FauxRequest:
 
@@ -63,7 +63,7 @@
         if plugins is not None:
             zcuf._setObject( 'plugins', plugins )
 
-        rcm = PASRAMCacheManager('ramcache')
+        rcm = RAMCacheManager('ramcache')
         zcuf._setObject('ramcache', rcm)
 
         return zcuf
@@ -112,7 +112,7 @@
         # by default
         self.assert_(zcuf.ZCacheable_getManager() is None)
 
         # Make sure the PASRAMCacheManager is empty
         self.assert_(len(rcm.getCacheReport()) == 0)
 
     def test_caching_in_PAS(self):
@@ -112,7 +112,7 @@
         self.assert_(zcuf.ZCacheable_getManager() is None)
 
-        # Make sure the PASRAMCacheManager is empty
+        # Make sure the RAMCacheManager is empty
         self.assert_(len(rcm.getCacheReport()) == 0)
 



More information about the Zope-CVS mailing list